@@ -50,9 +50,15 @@ class EasyPedidoInterfaceBase:
     def mark_variants_as_updated(self):
         pass
 
-    def update_variants(self, key_field_name, content=None):
-        content = content or self.get_variants_content()
-        if content and content != '':
+    def update_variants(self, key_field_name):
+        content = self.get_variants_content()
+        if content:
+            return self.send_updated_variants(key_field_name, content)
+        else:
+            return 'No hay productos para actualizar'
+
+    def send_updated_variants(self, key_field_name, content):
+        if content:
             data = {
                 "main_trade_id": self.main_trade_id,
                 "token": self.token,
@@ -72,4 +78,3 @@ class EasyPedidoInterfaceBase:
             return response.content
 
 
-
